@@ -5,7 +5,7 @@
 */
 #pragma once
 
-#include <Item>
+#include <Akonadi/Item>
 #include <QDialog>
 class QLineEdit;
 class KJob;
@@ -18,7 +18,7 @@ class NotesAgentNoteDialog : public QDialog
     Q_OBJECT
 public:
     explicit NotesAgentNoteDialog(QWidget *parent = nullptr);
-    ~NotesAgentNoteDialog();
+    ~NotesAgentNoteDialog() override;
 
     void setNoteId(Akonadi::Item::Id id);
 
