@@ -10,8 +10,12 @@
 
 #include "noteshared_export.h"
 #include <QDialog>
+
 class QDateTime;
 class QAbstractButton;
+class KDateComboBox;
+class KTimeComboBox;
+class QButtonGroup;
 namespace NoteShared
 {
 class NoteAlarmDialogPrivate;
@@ -26,7 +30,11 @@ public:
 
 private:
     void slotButtonChanged(QAbstractButton *button);
-    NoteAlarmDialogPrivate *const d;
+
+private:
+    KDateComboBox *m_atDate = nullptr;
+    KTimeComboBox *m_atTime = nullptr;
+    QButtonGroup *m_buttons = nullptr;
 };
 }
 
